// module aliases
var Engine = Matter.Engine,
    Render = Matter.Render,
    World = Matter.World,
    Bodies = Matter.Bodies,
    MouseConstraint = Matter.MouseConstraint,
    Constraint = Matter.Constraint,
    Body = Matter.Body,
    Composites = Matter.Composites,
    Composite = Matter.Composite,
	Mouse = Matter.Mouse,
	Vertices = Matter.Vertices,
	Common = Matter.Common,
    Runner = Matter.Runner,
    Events = Matter.Events;

// create an engine
var engine = Engine.create(),
 world = engine.world;

// create a renderer
var render = Render.create({
    element: document.body,
    engine: engine,
    options: {
            wireframes: false //to show color
        }
});

Render.run(render);
// run the engine
Engine.run(engine);

// create runner
var runner = Runner.create();
Runner.run(runner, engine);

var ground = Bodies.rectangle(400, 610, 810, 60, { isStatic: true, friction: 1});

group = Body.nextGroup(true);

    var handle,
    handle_part1 = Bodies.rectangle(600, 576, 50, 16, { 
            chamfer: { radius: [2, 2, 0, 0] },
            friction: 1,
            collisionFilter: { group: group }
		}),

	handle_part2 = Bodies.rectangle(600, 548, 20, 40, { collisionFilter: { group: group } }),
	handle_part3 = Bodies.rectangle(600, 522, 30, 12, { 
            chamfer: { radius: [2, 2, 2, 2] },
            collisionFilter: { group: group }
		}),
	handle_part4 = Bodies.rectangle(600, 481, 20, 70, { collisionFilter: { group: group } }),
	handle_part5 = Bodies.rectangle(600, 440, 30, 12, { 
            chamfer: { radius: [2, 2, 2, 2] },
            collisionFilter: { group: group }
		});

	var vertices = [{x: 20, y: 120}, {x: 24, y: 120}, {x: 26, y: 130}, {x: 74, y: 130}, {x: 76, y: 120}, {x: 80, y: 120}, {x: 75, y: 135}, {x: 25, y: 135}];
	var vertices2 = [{x: 16, y: 90}, {x: 24, y: 90}, {x: 28, y: 120}, {x: 20, y: 120}];
	var vertices3 = [{x: 76, y: 90}, {x: 84, y: 90}, {x: 80, y: 120}, {x: 72, y: 120}];

    var cup_part1 = Bodies.fromVertices(600, 430, vertices, { render: {
                fillStyle: 'grey',
                strokeStyle: 'grey',
                lineWidth: 1
            }
    }, true),
    cup_part2 = Bodies.fromVertices(572, 404, vertices2, { render: {
                fillStyle: 'grey',
                strokeStyle: 'grey',
                lineWidth: 1
            }
    }, true),
    cup_part3 = Bodies.fromVertices(628, 404, vertices3, { render: {
                strokeStyle: 'grey',
				fillStyle: 'grey',
                lineWidth: 1
            }
    }, true);

// add mouse control
    var mouse = Mouse.create(render.canvas),
        mouseConstraint = MouseConstraint.create(engine, {
            mouse: mouse,
            constraint: {
                stiffness: 1,
                render: {
                    visible: false
                }
            }
});

World.add(world, mouseConstraint);


	var compoundBody = Body.create({
        parts: [handle_part1, handle_part2, handle_part3, handle_part4, handle_part5, cup_part1, cup_part2, cup_part3],
        inertia: Infinity,
        /*render: {
                    visible: false
        }*/
        collisionFilter: { group: group },
    });

// keep the mouse in sync with rendering
render.mouse = mouse;

World.add(world, ground);

    
    var bilbocquet = Composite.create();

    var rope = Composites.stack(200, 100, 40, 1, 1, 1, function(x, y) {
        return Bodies.circle(x, y, 1, { collisionFilter: { group: group }, render: { visible:false } });
    });
    
    Composites.chain(rope, 0, 0, 0, 0, { stiffness: 1, length: 0 });


    var ball = Bodies.circle(198, 150, 20, { collisionFilter: { group: group }, render: { visible: true } });

    Composite.add(bilbocquet, rope);
    Composite.add(bilbocquet, ball);
    Composite.add(bilbocquet, compoundBody);
    Composite.add(bilbocquet, Constraint.create({ 
        bodyB: rope.bodies[rope.bodies.length - 2],
        bodyA: ball,
        stiffness: 1,
        length: 2
    }));

    Composite.add(bilbocquet, Constraint.create({ 
        bodyB: rope.bodies[0],
        bodyA: compoundBody,
        stiffness: 1,
        length: 1
    }));

Events.on(mouseConstraint, 'startdrag', function(event) {

    if(event.body.id == compoundBody.id){
        compoundBody.collisionFilter.group = 1000000;
    }
    
});

Events.on(mouseConstraint, 'enddrag', function(event) {
    
    if(event.body.id == compoundBody.id){
        compoundBody.collisionFilter.group = group;
    }

});

    
World.add(world, bilbocquet);






